@@ -7,5 +7,5 @@ mod meta;
 pub use crate::backend::build;
 pub use crate::interface::{
     bit_vector::BitVector, common::bit_patterns, common::io, common::util, int_vector::IntVector,
-    rank_support_v::RankSupportV, rrr_vector::RrrVector,
+    rank_support_v::RankSupportV, rrr_vector::RrrVector, select_support_mcl::SelectSupportMcl,
 };
